{% include 'doctype.html'%}
    <head>
		<meta charset="utf-8" />
		<title>Health check - invalid</title>

		<meta name="viewport" content="width=device-width, initial-scale=1.0" />
		<link rel="shortcut icon" type="image/ico" href="{{STATIC_URL}}img/favicon.ico" />

	</head>

	<body>
        <h1>Uh Oh</h1>
        <h2>{{error}}</h2>
	</body>
</html>
